@@ -31,7 +31,7 @@ class Environment(MutableMapping):
         self.prefix = prefix
         self.prefixf = lambda x: x if not prefix else f"{prefix}_{x}"
 
-    def _expand(self, value):
+    def expand_variables(self, value):
         if type(value) is not str:
             return value
 
@@ -64,7 +64,8 @@ class Environment(MutableMapping):
             return mapper(value)
 
         if default is None and not nullable:
-            raise Exception(f"{key} not found. Declare it as environment variable or provide a default value.")
+            raise KeyError(key)
+            # raise Exception(f"{key} not found. Declare it as environment variable or provide a default value.")
 
         return mapper(default)
 
@@ -72,7 +73,7 @@ class Environment(MutableMapping):
         return self.get(key, default, nullable, cast)
 
     def __setitem__(self, key, value):
-        self._data[key] = self._expand(value)
+        self._data[key] = self.expand_variables(value)
 
     def __getitem__(self, key):
         return self._data[key]
@@ -135,3 +136,13 @@ def enrich_environ(*env_files, **kwargs):
     for key, value in DotEnv(*env_files, **kwargs).items():
         if key not in os.environ:
             os.environ[key] = value
+
+
+def path_mapper(path: str) -> str:
+    path = os.path.expanduser(path)
+    path = os.path.expandvars(path)
+    path = os.path.abspath(path)
+    path = os.path.realpath(path, strict=True)
+    path = os.path.normpath(path)
+
+    return path
