@@ -10,7 +10,7 @@ class TraversalOptions:
         self.relative = kwargs.get("relative", False)
         self.inclusion = kwargs.get("inclusion", None)
         self.exclusion = kwargs.get("exclusion", None)
-        self.ignore_folders = kwargs.get("ignore_folders", [])
+        self.ignore_folders = [os.path.realpath(p) for p in kwargs.get("ignore_folders", [])]
         self.ext = kwargs.get("ext", None)
         self.limit = kwargs.get("limit", None)
 
@@ -41,7 +41,8 @@ def ls_files(folder, **kwargs) -> Iterator[os.DirEntry]:
         for entry in os.scandir(q.get()):
             if opts.recursive and entry.is_dir(follow_symlinks=False):
                 _, folder = os.path.split(entry.path)
-                if folder.strip(os.sep) not in opts.ignore_folders:
+                folder = os.path.realpath(folder)
+                if folder not in opts.ignore_folders:
                     q.put(entry.path)
                 continue
 
@@ -65,10 +66,24 @@ def ls_files(folder, **kwargs) -> Iterator[os.DirEntry]:
             yield entry
 
 
+def transform_add_suffix(suffix: str):
+    def transform(path):
+        return f"{path}{suffix}"
+
+    return transform
+
+
 def transform_snake_case(path: str):
     return '_'.join(path.split()).replace('&', "and").replace('-', '_').lower()
 
 
+def transform_with_regex(pattern, repl):
+    def transform(path):
+        return re.sub(pattern, repl, path)
+
+    return transform
+
+
 def rename_files(dir, func, noop=False, **kwargs):
     for entry in ls_files(dir, **kwargs):
         parent, _ = os.path.split(entry.path)
